# RelationshipCommonName

The common name associated with the subscription generated by Fastly TLS. Optional. If you do not pass a common name on create, we will default to the first TLS domain included. If provided, the domain chosen as the common name must be included in TLS domains.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**common_name** | [**RelationshipMemberTlsDomain**](RelationshipMemberTlsDomain.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


